@@ -15,7 +15,7 @@ use Module::Build::Base;
 
 use vars qw($VERSION @ISA);
 @ISA = qw(Module::Build::Base);
-$VERSION = '0.33';
+$VERSION = '0.36';
 $VERSION = eval $VERSION;
 
 # Okay, this is the brute-force method of finding out what kind of
@@ -110,6 +110,11 @@ sub is_unixish { return ((os_type() || '') eq 'Unix') }
 
 __END__
 
+=for :stopwords
+bindoc binhtml destdir distcheck distclean distdir distmeta distsign disttest
+fakeinstall html installdirs installsitebin installsitescript installvendorbin
+installvendorscript libdoc libhtml pardist ppd ppmdist realclean skipcheck
+testall testcover testdb testpod testpodcoverage versioninstall
 
 =head1 NAME
 
@@ -162,25 +167,25 @@ This illustrates initial configuration and the running of three
 'actions'.  In this case the actions run are 'build' (the default
 action), 'test', and 'install'.  Other actions defined so far include:
 
-  build                          manpages    
-  clean                          pardist     
-  code                           ppd         
-  config_data                    ppmdist     
-  diff                           prereq_data 
-  dist                           prereq_report
-  distcheck                      pure_install
-  distclean                      realclean   
-  distdir                        retest      
-  distmeta                       skipcheck   
-  distsign                       test        
-  disttest                       testall     
-  docs                           testcover   
-  fakeinstall                    testdb      
-  help                           testpod     
-  html                           testpodcoverage
-  install                        versioninstall
-  manifest                                   
-
+  build                          manpages
+  clean                          pardist
+  code                           patch_blead
+  config_data                    ppd
+  diff                           ppmdist
+  dist                           prereq_data
+  distcheck                      prereq_report
+  distclean                      pure_install
+  distdir                        realclean
+  distmeta                       retest
+  distsign                       skipcheck
+  disttest                       test
+  docs                           testall
+  fakeinstall                    testcover
+  help                           testdb
+  html                           testpod
+  install                        testpodcoverage
+  installdeps                    versioninstall
+  manifest
 
 You can run the 'help' action for a complete list of actions.
 
@@ -251,7 +256,7 @@ The following build actions are provided by default.
 If you run the C<Build> script without any arguments, it runs the
 C<build> action, which in turn runs the C<code> and C<docs> actions.
 
-This is analogous to the MakeMaker 'make all' target.
+This is analogous to the C<MakeMaker> I<make all> target.
 
 =item clean
 
@@ -265,7 +270,7 @@ C<_build/> directory and the C<Build> script itself).
 
 [version 0.20]
 
-This action builds your codebase.
+This action builds your code base.
 
 By default it just creates a C<blib/> directory and copies any C<.pm>
 and C<.pod> files from your C<lib/> directory into the C<blib/>
@@ -313,7 +318,7 @@ tarball of the files listed in F<MANIFEST> and compress the tarball using
 GZIP compression.
 
 By default, this action will use the C<Archive::Tar> module. However, you can
-force it to use binary "tar" and "gzip" executables by supplying an explicit 
+force it to use binary "tar" and "gzip" executables by supplying an explicit
 C<tar> (and optional C<gzip>) parameter:
 
   ./Build dist --tar C:\path\to\tar.exe --gzip C:\path\to\zip.exe
@@ -346,12 +351,12 @@ This directory is what the distribution tarball is created from.
 
 Creates the F<META.yml> file that describes the distribution.
 
-F<META.yml> is a file containing various bits of "metadata" about the
+F<META.yml> is a file containing various bits of I<metadata> about the
 distribution.  The metadata includes the distribution name, version,
 abstract, prerequisites, license, and various other data about the
 distribution.  This file is created as F<META.yml> in YAML format.
-It is recommended that the C<YAML> module be installed to create it.
-If the C<YAML> module is not installed, an internal module supplied
+It is recommended that the C<YAML::Tiny> module be installed to create it.
+If the C<YAML::Tiny> module is not installed, an internal module supplied
 with Module::Build will be used to write the META.yml file, and this
 will most likely be fine.
 
@@ -381,13 +386,13 @@ that directory.
 
 [version 0.20]
 
-This will generate documentation (e.g. Unix man pages and html
+This will generate documentation (e.g. Unix man pages and HTML
 documents) for any installable items under B<blib/> that
 contain POD.  If there are no C<bindoc> or C<libdoc> installation
 targets defined (as will be the case on systems that don't support
 Unix manpages) no action is taken for manpages.  If there are no
 C<binhtml> or C<libhtml> installation targets defined no action is
-taken for html documents.
+taken for HTML documents.
 
 =item fakeinstall
 
@@ -440,6 +445,24 @@ This can be a good idea, as it helps prevent multiple versions of a
 module from being present on your system, which can be a confusing
 situation indeed.
 
+=item installdeps
+
+[version 0.36]
+
+This action will use the C<cpan_client> parameter as a command to install
+missing prerequisites.  You will be prompted whether to install
+optional dependencies.
+
+The C<cpan_client> option defaults to 'cpan' but can be set as an option or in
+F<.modulebuildrc>.  It must be a shell command that takes a list of modules to
+install as arguments (e.g. 'cpanp -i' for CPANPLUS).  If the program part is a
+relative path (e.g. 'cpan' or 'cpanp'), it will be located relative to the perl
+program that executed Build.PL.
+
+  /opt/perl/5.8.9/bin/perl Build.PL
+  ./Build installdeps --cpan_client 'cpanp -i'
+  # installs to 5.8.9
+
 =item manifest
 
 [version 0.05]
@@ -494,7 +517,7 @@ installed on your system.
 Build a PPD file for your distribution.
 
 This action takes an optional argument C<codebase> which is used in
-the generated ppd file to specify the (usually relative) URL of the
+the generated PPD file to specify the (usually relative) URL of the
 distribution.  By default, this value is the distribution name without
 any path information.
 
@@ -507,7 +530,7 @@ Example:
 [version 0.23]
 
 Generates a PPM binary distribution and a PPD description file.  This
-action also invokes the 'ppd' action, so it can accept the same
+action also invokes the C<ppd> action, so it can accept the same
 C<codebase> argument described under that action.
 
 This uses the same mechanism as the C<dist> action to tar & zip its
@@ -518,7 +541,7 @@ the result.
 
 [version 0.32]
 
-This action prints out a Perl data structure of all prerequsites and the versions
+This action prints out a Perl data structure of all prerequisites and the versions
 required.  The output can be loaded again using C<eval()>.  This can be useful for
 external tools that wish to query a Build script for prerequisites.
 
@@ -536,7 +559,7 @@ for a bug report.
 [version 0.28]
 
 This action is identical to the C<install> action.  In the future,
-though, when C<install> starts writing to the file 
+though, when C<install> starts writing to the file
 F<$(INSTALLARCHLIB)/perllocal.pod>, C<pure_install> won't, and that
 will be the only difference between them.
 
@@ -612,7 +635,7 @@ or use a C<glob()>-style pattern:
 
 =item testall
 
-[verion 0.2807]
+[version 0.2807]
 
 [Note: the 'testall' action and the code snippets below are currently
 in alpha stage, see
@@ -661,7 +684,7 @@ argument.
 
 [version 0.25]
 
-This checks all the files described in the C<docs> action and 
+This checks all the files described in the C<docs> action and
 produces C<Test::Harness>-style output.  If you are a module author,
 this is useful to run before creating a new release.
 
@@ -669,7 +692,7 @@ this is useful to run before creating a new release.
 
 [version 0.28]
 
-This checks the pod coverage of the distribution and 
+This checks the pod coverage of the distribution and
 produces C<Test::Harness>-style output. If you are a module author,
 this is useful to run before creating a new release.
 
@@ -716,9 +739,9 @@ respective action.
 NOTE: There is some preliminary support for options to use the more
 familiar long option style.  Most options can be preceded with the
 C<--> long option prefix, and the underscores changed to dashes
-(e.g. --use-rcfile).  Additionally, the argument to boolean options is
+(e.g. C<--use-rcfile>).  Additionally, the argument to boolean options is
 optional, and boolean options can be negated by prefixing them with
-'no' or 'no-' (e.g. --noverbose or --no-verbose).
+C<no> or C<no-> (e.g. C<--noverbose> or C<--no-verbose>).
 
 =over 4
 
@@ -726,15 +749,20 @@ optional, and boolean options can be negated by prefixing them with
 
 Suppress informative messages on output.
 
+=item verbose
+
+Display extra information about the Build on output.
+
+=item cpan_client
+
+Sets the C<cpan_client> command for use with the C<installdeps> action.
+See C<installdeps> for more details.
+
 =item use_rcfile
 
 Load the F<~/.modulebuildrc> option file.  This option can be set to
 false to prevent the custom resource file from being loaded.
 
-=item verbose
-
-Display extra information about the Build on output.
-
 =item allow_mb_mismatch
 
 Suppresses the check upon startup that the version of Module::Build
@@ -742,8 +770,12 @@ we're now running under is the same version that was initially invoked
 when building the distribution (i.e. when the C<Build.PL> script was
 first run).  Use with caution.
 
-=back
+=item debug
 
+Prints Module::Build debugging information to STDOUT, such as a trace of
+executed build actions.
+
+=back
 
 =head2 Default Options File (F<.modulebuildrc>)
 
@@ -772,15 +804,35 @@ key C<*> (asterisk) denotes any global options that should be applied
 to all actions, and the key 'Build_PL' specifies options to be applied
 when you invoke C<perl Build.PL>.
 
-  *        verbose=1   # global options
-  diff     flags=-u
-  install  --install_base /home/ken
-           --install_path html=/home/ken/docs/html
+  *           verbose=1   # global options
+  diff        flags=-u
+  install     --install_base /home/ken
+              --install_path html=/home/ken/docs/html
+  installdeps --cpan_client 'cpanp -i'
 
 If you wish to locate your resource file in a different location, you
-can set the environment variable 'MODULEBUILDRC' to the complete
+can set the environment variable C<MODULEBUILDRC> to the complete
 absolute path of the file containing your options.
 
+=head2 Environment variables
+
+=over
+
+=item MODULEBUILDRC
+
+[version 0.28]
+
+Specifies an alternate location for a default options file as described above.
+
+=item PERL_MB_OPT
+
+[version 0.36]
+
+Command line options that are applied to Build.PL or any Build action.  The
+string is split as the shell would (e.g. whitespace) and the result is
+prepended to any actual command-line arguments.
+
+=back
 
 =head1 INSTALL PATHS
 
@@ -807,7 +859,7 @@ Usually pure-Perl module files ending in F<.pm>.
 =item arch
 
 "Architecture-dependent" module files, usually produced by compiling
-XS, Inline, or similar code.
+XS, L<Inline>, or similar code.
 
 =item script
 
@@ -835,11 +887,11 @@ pages belonging to the 'man3' category.
 
 =item binhtml
 
-This is the same as C<bindoc> above, but applies to html documents.
+This is the same as C<bindoc> above, but applies to HTML documents.
 
 =item libhtml
 
-This is the same as C<bindoc> above, but applies to html documents.
+This is the same as C<bindoc> above, but applies to HTML documents.
 
 =back
 
@@ -869,7 +921,7 @@ parameter as follows:
   binhtml => installhtml1dir installsitehtml1dir installvendorhtml1dir [*]
   libhtml => installhtml3dir installsitehtml3dir installvendorhtml3dir [*]
 
-  * Under some OS (eg. MSWin32) the destination for html documents is
+  * Under some OS (eg. MSWin32) the destination for HTML documents is
     determined by the C<Config.pm> entry C<installhtmldir>.
 
 The default value of C<installdirs> is "site".  If you're creating
@@ -887,7 +939,7 @@ with perl itself (i.e. a "core module"), then you may set
 C<installdirs> to "core" to overwrite the module in its present
 location.
 
-(Note that the 'script' line is different from MakeMaker -
+(Note that the 'script' line is different from C<MakeMaker> -
 unfortunately there's no such thing as "installsitescript" or
 "installvendorscript" entry in C<Config.pm>, so we use the
 "installsitebin" and "installvendorbin" entries to at least get the
@@ -922,7 +974,7 @@ system, you'll install as follows:
   binhtml => /home/ken/html
   libhtml => /home/ken/html
 
-Note that this is I<different> from how MakeMaker's C<PREFIX>
+Note that this is I<different> from how C<MakeMaker>'s C<PREFIX>
 parameter works.  C<install_base> just gives you a default layout under the
 directory you specify, which may have little to do with the
 C<installdirs=site> layout.
@@ -950,10 +1002,10 @@ platform you're installing on.
 
 =item prefix
 
-Provided for compatibility with ExtUtils::MakeMaker's PREFIX argument.
+Provided for compatibility with C<ExtUtils::MakeMaker>'s PREFIX argument.
 C<prefix> should be used when you wish Module::Build to install your
 modules, documentation and scripts in the same place
-ExtUtils::MakeMaker does.
+C<ExtUtils::MakeMaker> does.
 
 The following are equivalent.
 
@@ -961,13 +1013,13 @@ The following are equivalent.
     perl Makefile.PL PREFIX=/tmp/foo
 
 Because of the very complex nature of the prefixification logic, the
-behavior of PREFIX in MakeMaker has changed subtly over time.
+behavior of PREFIX in C<MakeMaker> has changed subtly over time.
 Module::Build's --prefix logic is equivalent to the PREFIX logic found
-in ExtUtils::MakeMaker 6.30.
+in C<ExtUtils::MakeMaker> 6.30.
 
-If you do not need to retain compatibility with ExtUtils::MakeMaker or
-are starting a fresh Perl installation we recommand you use
-C<install_base> instead (and C<INSTALL_BASE> in ExtUtils::MakeMaker).
+If you do not need to retain compatibility with C<ExtUtils::MakeMaker> or
+are starting a fresh Perl installation we recommend you use
+C<install_base> instead (and C<INSTALL_BASE> in C<ExtUtils::MakeMaker>).
 See L<Module::Build::Cookbook/Instaling in the same location as
 ExtUtils::MakeMaker> for further information.
 
@@ -978,13 +1030,13 @@ ExtUtils::MakeMaker> for further information.
 =head1 MOTIVATIONS
 
 There are several reasons I wanted to start over, and not just fix
-what I didn't like about MakeMaker:
+what I didn't like about C<MakeMaker>:
 
 =over 4
 
 =item *
 
-I don't like the core idea of MakeMaker, namely that C<make> should be
+I don't like the core idea of C<MakeMaker>, namely that C<make> should be
 involved in the build process.  Here are my reasons:
 
 =over 4
@@ -1009,25 +1061,25 @@ build/install process to do what they want.
 
 =item *
 
-There are several architectural decisions in MakeMaker that make it
+There are several architectural decisions in C<MakeMaker> that make it
 very difficult to customize its behavior.  For instance, when using
-MakeMaker you do C<use ExtUtils::MakeMaker>, but the object created in
+C<MakeMaker> you do C<use ExtUtils::MakeMaker>, but the object created in
 C<WriteMakefile()> is actually blessed into a package name that's
 created on the fly, so you can't simply subclass
 C<ExtUtils::MakeMaker>.  There is a workaround C<MY> package that lets
-you override certain MakeMaker methods, but only certain explicitly
-preselected (by MakeMaker) methods can be overridden.  Also, the method
+you override certain C<MakeMaker> methods, but only certain explicitly
+preselected (by C<MakeMaker>) methods can be overridden.  Also, the method
 of customization is very crude: you have to modify a string containing
 the Makefile text for the particular target.  Since these strings
 aren't documented, and I<can't> be documented (they take on different
 values depending on the platform, version of perl, version of
-MakeMaker, etc.), you have no guarantee that your modifications will
-work on someone else's machine or after an upgrade of MakeMaker or
+C<MakeMaker>, etc.), you have no guarantee that your modifications will
+work on someone else's machine or after an upgrade of C<MakeMaker> or
 perl.
 
 =item *
 
-It is risky to make major changes to MakeMaker, since it does so many
+It is risky to make major changes to C<MakeMaker>, since it does so many
 things, is so important, and generally works.  C<Module::Build> is an
 entirely separate package so that I can work on it all I want, without
 worrying about backward compatibility.
@@ -1081,7 +1133,7 @@ modify it under the same terms as Perl itself.
 =head1 SEE ALSO
 
 perl(1), L<Module::Build::Cookbook>, L<Module::Build::Authoring>,
-L<Module::Build::API>, L<ExtUtils::MakeMaker>, L<YAML>
+L<Module::Build::API>, L<ExtUtils::MakeMaker>, L<YAML::Tiny>
 
 F<META.yml> Specification:
 L<http://module-build.sourceforge.net/META-spec-current.html>
